pub type TypeObj = Box<dyn Type>;Expand description
Since we can’t store the Type trait in the arena, we store boxed dyn objects of it instead.
Aliased Type
pub struct TypeObj(/* private fields */);pub type TypeObj = Box<dyn Type>;Since we can’t store the Type trait in the arena, we store boxed dyn objects of it instead.
pub struct TypeObj(/* private fields */);